@@ -4,7 +4,7 @@ from mprop import mproperty
 from subprocess import Popen, PIPE
 import sys
 
-__version__ = "0.101.0"
+__version__ = "0.103.1"
 
 __github_repo = "jupyter-naas/drivers"
 
@@ -413,3 +413,10 @@ def huggingface():
     from naas_drivers.tools.huggingface import Huggingface
 
     return Huggingface()
+
+
+@load_driver(extra_requires="snowflake")
+def snowflake():
+    from naas_drivers.tools.snowflake import Snowflake
+
+    return Snowflake()
