@@ -557,9 +557,6 @@ class Profile(LinkedIn):
                 break
         # Cleaning
         if len(df) > 0:
-            df.PUBLISHED_DATE = pd.to_datetime(df.PUBLISHED_DATE).dt.tz_localize(
-                "Europe/Paris"
-            )
             df.PUBLISHED_DATE = df.PUBLISHED_DATE.astype(str)
         return df.reset_index(drop=True)
 
@@ -1399,7 +1396,6 @@ class Company(LinkedIn):
         - PUBLIC_ID                     object
         - FOLLOWED_AT                   object
         - DISTANCE                      object
-        - STATUS                        object
         - DATE_EXTRACT                  object
 
         Parameters
@@ -1445,6 +1441,8 @@ class Company(LinkedIn):
                 limit -= count
             if sleep:
                 time.sleep(TIME_SLEEP)
+        if len(df) > 0:
+            df = df.sort_values(by="FOLLOWED_AT", ascending=False)
         return df.reset_index(drop=True)
 
     def __get_posts_views(self, activity_id):
@@ -1553,9 +1551,6 @@ class Company(LinkedIn):
                 break
         # Cleaning
         if len(df) > 0:
-            df.PUBLISHED_DATE = pd.to_datetime(df.PUBLISHED_DATE).dt.tz_localize(
-                "Europe/Paris"
-            )
             df.PUBLISHED_DATE = df.PUBLISHED_DATE.astype(str)
 
             # Add views + engagement score
